==> smartgwt-5.0p.zip: com/smartgwt/client/docs/Grouping.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to Grouping.
 * @see com.smartgwt.client.widgets.calendar.Calendar#groupLanesBy
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupValue
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupTitle
 * @see com.smartgwt.client.widgets.grid.ListGrid#groupBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getOriginalData
 * @see com.smartgwt.client.widgets.calendar.Calendar#getLaneGroupStartOpen
 * @see com.smartgwt.client.widgets.grid.ListGrid#getOriginalData
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupTree
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupStartOpen
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCanCollapseGroup
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCollapseGroupOnRowClick
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupTitleField
 * @see com.smartgwt.client.widgets.grid.ListGrid#getShowGroupSummaryInHeader
 * @see com.smartgwt.client.widgets.grid.ListGrid#getShowCollapsedGroupSummary
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupingModes
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupingMode
 * @see com.smartgwt.client.widgets.grid.ListGridField#getDefaultGroupingMode
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupPrecision
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupGranularity
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupNodeStyle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupNodeBaseStyle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupIcon
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupIconSize
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupIndentSize
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupLeadingIndent
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCanGroupBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupByMaxRecords
 * @see com.smartgwt.client.widgets.grid.ListGrid#getIsGrouped
 * @see com.smartgwt.client.widgets.grid.ListGrid#getNullGroupTitle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupByField
 * @see com.smartgwt.client.widgets.grid.ListGrid#getSortByGroupFirst
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupSortDirection
 */
public interface Grouping {
}

==> smartgwt-6.1p.zip: com/smartgwt/client/docs/Grouping.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to Grouping.
 * @see com.smartgwt.client.widgets.calendar.Calendar#groupLanesBy
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupValue
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupTitle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupMembers
 * @see com.smartgwt.client.widgets.grid.ListGrid#groupBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getOriginalData
 * @see com.smartgwt.client.widgets.grid.GroupNode
 * @see com.smartgwt.client.data.GroupSpecifier
 * @see com.smartgwt.client.widgets.calendar.Calendar#getLaneGroupStartOpen
 * @see com.smartgwt.client.widgets.grid.GroupNode#getGroupMembers
 * @see com.smartgwt.client.widgets.grid.GroupNode#getGroupTitle
 * @see com.smartgwt.client.widgets.grid.GroupNode#getGroupValue
 * @see com.smartgwt.client.widgets.grid.ListGrid#getOriginalData
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupTree
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupStartOpen
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCanCollapseGroup
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCollapseGroupOnRowClick
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupTitleField
 * @see com.smartgwt.client.widgets.grid.ListGrid#getShowGroupSummaryInHeader
 * @see com.smartgwt.client.widgets.grid.ListGrid#getShowCollapsedGroupSummary
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupingModes
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupingMode
 * @see com.smartgwt.client.widgets.grid.ListGridField#getDefaultGroupingMode
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupPrecision
 * @see com.smartgwt.client.widgets.grid.ListGridField#getGroupGranularity
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupNodeStyle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupNodeBaseStyle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupIcon
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupIconSize
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupIndentSize
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupLeadingIndent
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCanGroupBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupByMaxRecords
 * @see com.smartgwt.client.widgets.grid.ListGrid#getIsGrouped
 * @see com.smartgwt.client.widgets.grid.ListGrid#getNullGroupTitle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupByField
 * @see com.smartgwt.client.widgets.grid.ListGrid#getSortByGroupFirst
 * @see com.smartgwt.client.widgets.grid.ListGrid#getGroupSortDirection
 */
public interface Grouping {
}
